@@ -1,6 +1,7 @@
 # Copyright (c) 2019 Ultimaker B.V.
 # Cura is released under the terms of the LGPLv3 or higher.
 from time import time
+import os
 from typing import List, Optional, cast
 
 from PyQt5.QtCore import QObject, QUrl, pyqtProperty, pyqtSignal, pyqtSlot
@@ -49,7 +50,7 @@ class CloudOutputDevice(UltimakerNetworkedPrinterOutputDevice):
     NETWORK_RESPONSE_CONSIDER_OFFLINE = 15.0  # seconds
 
     # The minimum version of firmware that support print job actions over cloud.
-    PRINT_JOB_ACTIONS_MIN_VERSION = Version("5.3.0")
+    PRINT_JOB_ACTIONS_MIN_VERSION = Version("5.2.12")
 
     # Notify can only use signals that are defined by the class that they are in, not inherited ones.
     # Therefore we create a private signal used to trigger the printersChanged signal.
@@ -124,11 +125,11 @@ class CloudOutputDevice(UltimakerNetworkedPrinterOutputDevice):
     def matchesNetworkKey(self, network_key: str) -> bool:
         # Typically, a network key looks like "ultimakersystem-aabbccdd0011._ultimaker._tcp.local."
         # the host name should then be "ultimakersystem-aabbccdd0011"
-        if network_key.startswith(self.clusterData.host_name):
+        if network_key.startswith(str(self.clusterData.host_name or "")):
             return True
         # However, for manually added printers, the local IP address is used in lieu of a proper
-        # network key, so check for that as well
-        if self.clusterData.host_internal_ip is not None and network_key in self.clusterData.host_internal_ip:
+        # network key, so check for that as well. It is in the format "manual:10.1.10.1".
+        if network_key.endswith(str(self.clusterData.host_internal_ip or "")):
             return True
         return False
 
@@ -191,8 +192,9 @@ class CloudOutputDevice(UltimakerNetworkedPrinterOutputDevice):
     def _onPrintJobCreated(self, job: ExportFileJob) -> None:
         output = job.getOutput()
         self._tool_path = output  # store the tool path to prevent re-uploading when printing the same file again
+        file_name = job.getFileName()
         request = CloudPrintJobUploadRequest(
-            job_name=job.getFileName(),
+            job_name=os.path.splitext(file_name)[0],
             file_size=len(output),
             content_type=job.getMimeType(),
         )
