@@ -3,10 +3,10 @@
 
 CuraAppName = "cura"
 CuraAppDisplayName = "Ultimaker Cura"
-CuraVersion = "4.5.0"
+CuraVersion = "4.6.2"
 CuraBuildType = ""
 CuraDebugMode = True if "" == "ON" else False
-CuraCloudAPIRoot = ""
+CuraCloudAPIRoot = "https://api.ultimaker.com"
 CuraCloudAPIVersion = "1"
-CuraCloudAccountAPIRoot = ""
+CuraCloudAccountAPIRoot = "https://account.ultimaker.com"
 CuraMarketplaceRoot = ""
